<?php
/*
Plugin Name: RatePanel API (WooCommerce)
Plugin URI: https://ratepanel.com
Description: Plugin to connect for RatePanel API
Author: RatePanel
Author URI: https://www.ratepanel.com
Version: 0.2b

	Copyright: © 2015 RatePanel (email : info@ratepanel.com)
	License: GNU General Public License v3.0
	License URI: http://www.gnu.org/licenses/gpl-3.0.html
*/

if(!defined('ABSPATH'))
{
    exit; // Exit if accessed directly
}

/**
 * Check if WooCommerce is active
 */
if(in_array( 'woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))))
{
	
	if (!class_exists('WC_Ratepanel'))
    {
		
		/**
		 * Localisation
		 **/
		load_plugin_textdomain('WC_Ratepanel', false, dirname(plugin_basename(__FILE__)) . '/');

		class WC_RatepanelAPI
        {
			public function __construct()
            {
				add_action('woocommerce_order_status_changed', array(&$this, 'orderStatusChanged'));

                if(is_admin())
                {
                    add_action('admin_menu', array(&$this, 'admin_menu'));
                    add_action('admin_init', array(&$this, 'admin_init'));
                }
			}

            /**
             * When a payment has been completed and a RatePanel invitation should be sent out
             * @param int $postId
             */
            public function orderStatusChanged($postId)
            {
                $key = get_option('ratepanelapi_key');
                $triggerStatus = get_option('ratepanelapi_trigger_status');

                if(!$triggerStatus || empty($triggerStatus))
                {
                    return;
                }

                if(!empty($key))
                {
                    $status = get_post_status($postId);
                    if($status === $triggerStatus) {
                        $email = get_post_meta($postId, '_billing_email', true);
                        $firstname = get_post_meta($postId, '_billing_first_name', true);
                        $lastname = get_post_meta($postId, '_billing_last_name', true);

                        $curl = curl_init();
                        curl_setopt($curl, CURLOPT_POST, 1);
                        curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
                        curl_setopt($curl, CURLOPT_USERPWD, 'api:' . $key);
                        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
                        curl_setopt($curl, CURLOPT_URL, 'https://api.ratepanel.com/customer');
                        curl_setopt($curl, CURLOPT_POSTFIELDS, array(
                            'name' => $firstname . ' ' . $lastname,
                            'email' => $email,
                            'order_number' => $postId,
                            'invite' => 1
                        ));
                        curl_exec($curl);
                        curl_close($curl);
                    }
                }
            }

            /**
             * Init
             */
            public function admin_init()
            {
                register_setting('ratepanelapi_settings', 'ratepanelapi_key');
                register_setting('ratepanelapi_settings', 'ratepanelapi_trigger_status');
            }

            /**
             * Admin menu
             */
            public function admin_menu()
            {
                add_menu_page('Ratepanel API Settings', 'Ratepanel API', 'manage_options', 'id_ratepanelapi', array(&$this, 'settings'));
            }

            /**
             * Settings page for plugin
             */
            public function settings()
            {
                if(!current_user_can('manage_options'))
                {
                    wp_die(__('You do not have sufficient permissions to access this page.'));
                }

                require('admin.view.php');
            }
		}

		//finally instantiate our plugin class and add it to the set of globals
		$GLOBALS['wc_ratepanel'] = new WC_RatepanelAPI();
	}
}